[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- pyhsm: the pyhsm package
  - pyhsm.aead_cmd: implementations of AEAD commands for the YubiHSM
  - pyhsm.aes_ecb_cmd: implementations of AES ECB block cipher commands to execute on a YubiHSM
  - pyhsm.base: module for accessing a YubiHSM
  - pyhsm.basic_cmd: implementations of basic commands to execute on a YubiHSM
  - pyhsm.buffer_cmd: implementations of internal buffer commands for YubiHSM
  - pyhsm.cmd: module for accessing a YubiHSM
  - pyhsm.db_cmd: implementations of internal DB commands for YubiHSM
  - pyhsm.debug_cmd: implementations of debugging commands to execute on a YubiHSM
  - pyhsm.defines: Various defines from pyhsm_if.h.
  - pyhsm.exception: common exceptions for the pyhsm package
  - pyhsm.hmac_cmd: implementations of HMAC commands to execute on a YubiHSM
  - pyhsm.oath_hotp: helper functions to work with OATH HOTP (RFC4226) OTP's and YubiHSM
  - pyhsm.soft_hsm: functions for implementing parts of the HSMs machinery in software
  - pyhsm.stick: module for actually talking to the YubiHSM
  - pyhsm.stick_client: module for talking to the YubiHSM over a socket.
  - pyhsm.util: collection of utility functions
  - pyhsm.validate_cmd: implementations of validation commands for YubiHSM
  - pyhsm.version: module for keeping track of different capabilities in different versions
  - pyhsm.yubikey: helper functions to work with Yubikeys and YubiHSM